/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
import { BaseComponent } from '../../base.component';
import { Page } from '@playwright/test';
import { SearchPage, SearchType } from '../../../pages';
type FilterTab = 'Created' | 'Modified';
interface FilterFilesByDateParams {
    searchPage: SearchPage;
    filterType: 'anytime' | 'inTheLast' | 'between';
    dateFilterTab: FilterTab;
    searchPhrase: string;
    searchType: SearchType;
    expectSearchResults: number;
    inTheLastInputValue?: string;
    startDay?: string;
    endDay?: string;
}
export declare class SearchFiltersDate extends BaseComponent {
    private static rootElement;
    constructor(page: Page);
    createdTab: import("playwright-core").Locator;
    modifiedTab: import("playwright-core").Locator;
    createdTabTitle: import("playwright-core").Locator;
    modifiedTabTitle: import("playwright-core").Locator;
    anytimeButton: import("playwright-core").Locator;
    anytimeRadioButton: import("playwright-core").Locator;
    inTheLastButton: import("playwright-core").Locator;
    inTheLastInput: import("playwright-core").Locator;
    inTheLastDropdown: import("playwright-core").Locator;
    betweenButton: import("playwright-core").Locator;
    betweenRadioButton: import("playwright-core").Locator;
    betweenStartDate: import("playwright-core").Locator;
    betweenEndDate: import("playwright-core").Locator;
    openCreatedModifiedTab(page: SearchPage, tab: FilterTab): Promise<void>;
    /**
     * Method used in cases where we want to filter search results by Date
     *
     * @param searchPage page context for the test
     * @param filterType filter type for the Date filter
     * @param dateFilterTab tab in Date filter. Either Created or Modified
     * @param searchPhrase search phrase for the search
     * @param searchType type of items we want in search results e.g. files or folders
     * @param expectSearchResults expect a number of search results
     * @param inTheLastInputValue a value for 'in the last' input. e.g. in the last X days
     * @param startDay start day for time-frame search. DD-MMMM-YY
     * @param endDay end day for time-frame search. DD-MMMM-YY
     */
    filterFilesByDate(params: FilterFilesByDateParams): Promise<void>;
    isModifiedTabSelected(): Promise<string>;
    isSearchTabSelected(): Promise<string>;
}
export {};
